<?php

namespace Drupal\popin\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\SessionManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a 'PopinBlock' block.
 *
 * @Block(
 *  id = "popin_block",
 *  admin_label = @Translation("Popin block"),
 * )
 */
class PopinBlock extends BlockBase implements ContainerFactoryPluginInterface  {

  /**
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new testBkco object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
  }
  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new PopinBlock(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->configFactory->get('popin.popinconfig')->get();
    $build = [
      '#cache' => [
        'tags' => ['popin'],
      ],
    ];

    if(!isset($config['enabled']) || $config['enabled'] !== 1) {
      return $build;
    }
    $now = new DrupalDateTime();
    if(isset($config['datestart'])) {
      $dateStart = DrupalDateTime::createFromTimestamp($config['datestart']);
      if ($dateStart > $now) {
        return $build;
      }
    }
    if(isset($config['dateend'])) {
      $dateEnd = DrupalDateTime::createFromTimestamp($config['dateend']);
      if ($dateEnd < $now) {
        return $build;
      }
    }

    if (($image_style = ImageStyle::load('popin')) && isset($config['image'][0]) && is_numeric($config['image'][0]) && $image = File::load($config['image'][0])) {
      $config['image'] = $image_style->buildUrl($image->getFileUri());
    }

    $config['description'] = [
      '#type' => 'processed_text',
      '#text' => $config['description']['value'],
      '#format' => $config['description']['format'],
    ];

    $build['popin_block']['#theme'] = 'popin_block';
    $build['popin_block']['#config'] = $config;
    $build['#cache'] = ['max-age' => 0];
    $build['#attached']['library'][] = 'popin/popin';

    return $build;
  }

}
